==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Символ À',
	'barre_adresse' => 'Адреса ',
	'barre_aide' => 'Використовуйте SPIP-ярлики для форматування тексту',
	'barre_alignerdroite' => 'Абзац [/по правому краю/]',
	'barre_ancres' => 'Посилання',
	'barre_barre' => 'Перекреслити',
	'barre_bulle' => 'Допомога',
	'barre_c_cedille_maj' => 'Символ Ç',
	'barre_cadre' => 'Виділити &lt;cadre&gt;текст&lt;/cadre&gt;',
	'barre_caracteres' => 'Спеціальні символи',
	'barre_centrer' => '[|Центрувати|] абзац',
	'barre_chercher' => 'Знайти і замінити',
	'barre_clean' => 'Видалити HTML-теги з коду',
	'barre_code' => 'Редагувати &lt;code&gt;текст&lt;/code&gt;',
	'barre_desindenter' => 'Убрати відступ',
	'barre_e_accent_aigu' => 'Символ É',
	'barre_e_accent_grave' => 'Символ È',
	'barre_ea' => 'Символ æ',
	'barre_ea_maj' => 'Символ Æ',
	'barre_encadrer' => '[(Виділити)] абзац',
	'barre_eo' => 'Символ œ',
	'barre_eo_maj' => 'Символ Œ',
	'barre_euro' => 'Символ €',
	'barre_exposant' => 'Форматувати &lt;sup&gt;  текст (суперскрипт) t&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Спеціальне форматування',
	'barre_galerie' => 'Відкрити зображення',
	'barre_gestion_anc_bulle' => 'Допомога',
	'barre_gestion_anc_caption' => 'Посилання',
	'barre_gestion_anc_cible' => 'Посилання відкриється',
	'barre_gestion_anc_inserer' => 'Зробити посиланням',
	'barre_gestion_anc_nom' => 'Текст посилання',
	'barre_gestion_anc_pointer' => 'Вказівник на посилання',
	'barre_gestion_caption' => 'Умовні позначення',
	'barre_gestion_colonne' => 'Кільк. колонок',
	'barre_gestion_cr_casse' => 'Враховувати регістр',
	'barre_gestion_cr_changercasse' => 'Змінити регістр',
	'barre_gestion_cr_changercassemajuscules' => 'Зробити ВЕЛИКИМИ',
	'barre_gestion_cr_changercasseminuscules' => 'Зробити маленькими',
	'barre_gestion_cr_chercher' => 'Пошук',
	'barre_gestion_cr_entier' => 'Слова повністю',
	'barre_gestion_cr_remplacer' => 'Замінити',
	'barre_gestion_cr_tout' => 'Замінити все',
	'barre_gestion_entete' => 'Заголовок',
	'barre_gestion_ligne' => 'Кільк. рядків',
	'barre_gestion_taille' => 'Фіксований розмір',
	'barre_glossaire' => '[?glossaire] посилання (Wikipedia)',
	'barre_gras' => '{{Жирний}}',
	'barre_guillemets' => 'Виділити «подвійними лапками»',
	'barre_guillemets_simples' => 'Вставити між “лапок”',
	'barre_indenter' => 'Добавить відступ',
	'barre_inserer_cadre' => 'Вставити форматований текст (cadre)',
	'barre_inserer_caracteres' => 'Вставити спеціальні символи',
	'barre_inserer_code' => 'Виділення для програмного коду (code)',
	'barre_intertitre' => '{{{Підзаголовок}}}',
	'barre_italic' => '{Курсив}',
	'barre_langue' => 'Абревіатури',
	'barre_lien' => 'Зробити [посиланням->http://...]',
	'barre_lien_externe' => 'Зовнішнє посилання',
	'barre_lien_input' => 'Вкажіть адресу для цього посилання (ви можете вказати її в форматі URL http://www.monsite.com або просто написати номер статті).',
	'barre_liste_ol' => 'Нумерований список',
	'barre_liste_ul' => 'Список',
	'barre_lorem_ipsum' => 'Вставити пустий абзац',
	'barre_lorem_ipsum_3' => 'Вставити три пустих абзаци',
	'barre_miseenevidence' => '[*Підсвітити*] текст',
	'barre_note' => 'Зробити [[виноску]]',
	'barre_paragraphe' => 'Створити абзац',
	'barre_petitescapitales' => 'Написати &lt;sc&gt;малими &lt;/sc&gt;',
	'barre_poesie' => 'Форматування для &lt;poesie&gt;поезії&lt;/poesie&gt;',
	'barre_preview' => 'Поперед.перегляд',
	'barre_quote' => '<quote>Цитата</quote>',
	'barre_stats' => 'Статистика',
	'barre_tableau' => 'Додати або редагувати вибрану таблицю',

	// C
	'config_info_enregistree' => 'Налаштування збережено',

	// E
	'editer' => 'Редагувати',
	'explication_barre_outils_public' => 'CSS і Javascript сценарії для панелей інструментів (extension Porte Plume) будуть завантажені на сайт, і панель форматування тексту буде виводитися у форумах, в модулі коментарів та інших місцях, якщо їх конфігурації це дозволяють.',
	'explication_barre_outils_public_2' => 'Щоб максимально полегшити сайт і зменшити час його завантаження ви можете вимкнути додавання цих файлів. Тоді користувачі не зможуть форматувати текст при додаванні коментарів та в інших модулях.',

	// I
	'info_barre_outils_public' => 'Панель інструментів на сайті',
	'info_porte_plume_titre' => 'Налаштування панелі інструментів',

	// L
	'label_barre_outils_public_non' => 'Не додавати скрипти панелі інструментів на фронтенд сайту',
	'label_barre_outils_public_oui' => 'Додати скрипти для панелі інструментів на фронтенд сайту',

	// V
	'voir' => 'Поперед.перегляд'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Символ À',
	'barre_adresse' => 'Адреса ',
	'barre_aide' => 'Використовуйте SPIP-ярлики для форматування тексту',
	'barre_alignerdroite' => 'Абзац [/по правому краю/]',
	'barre_ancres' => 'Посилання',
	'barre_barre' => 'Перекреслити',
	'barre_bulle' => 'Допомога',
	'barre_c_cedille_maj' => 'Символ Ç',
	'barre_cadre' => 'Виділити &lt;cadre&gt;текст&lt;/cadre&gt;',
	'barre_caracteres' => 'Спеціальні символи',
	'barre_centrer' => '[|Центрувати|] абзац',
	'barre_chercher' => 'Знайти і замінити',
	'barre_clean' => 'Видалити HTML-теги з коду',
	'barre_code' => 'Редагувати &lt;code&gt;текст&lt;/code&gt;',
	'barre_desindenter' => 'Убрати відступ',
	'barre_e_accent_aigu' => 'Символ É',
	'barre_e_accent_grave' => 'Символ È',
	'barre_ea' => 'Символ æ',
	'barre_ea_maj' => 'Символ Æ',
	'barre_encadrer' => '[(Виділити)] абзац',
	'barre_eo' => 'Символ œ',
	'barre_eo_maj' => 'Символ Œ',
	'barre_euro' => 'Символ €',
	'barre_exposant' => 'Форматувати &lt;sup&gt;  текст (суперскрипт) t&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Спеціальне форматування',
	'barre_galerie' => 'Відкрити зображення',
	'barre_gestion_anc_bulle' => 'Допомога',
	'barre_gestion_anc_caption' => 'Посилання',
	'barre_gestion_anc_cible' => 'Посилання відкриється',
	'barre_gestion_anc_inserer' => 'Зробити посиланням',
	'barre_gestion_anc_nom' => 'Текст посилання',
	'barre_gestion_anc_pointer' => 'Вказівник на посилання',
	'barre_gestion_caption' => 'Умовні позначення',
	'barre_gestion_colonne' => 'Кільк. колонок',
	'barre_gestion_cr_casse' => 'Враховувати регістр',
	'barre_gestion_cr_changercasse' => 'Змінити регістр',
	'barre_gestion_cr_changercassemajuscules' => 'Зробити ВЕЛИКИМИ',
	'barre_gestion_cr_changercasseminuscules' => 'Зробити маленькими',
	'barre_gestion_cr_chercher' => 'Пошук',
	'barre_gestion_cr_entier' => 'Слова повністю',
	'barre_gestion_cr_remplacer' => 'Замінити',
	'barre_gestion_cr_tout' => 'Замінити все',
	'barre_gestion_entete' => 'Заголовок',
	'barre_gestion_ligne' => 'Кільк. рядків',
	'barre_gestion_taille' => 'Фіксований розмір',
	'barre_glossaire' => '[?glossaire] посилання (Wikipedia)',
	'barre_gras' => '{{Жирний}}',
	'barre_guillemets' => 'Виділити «подвійними лапками»',
	'barre_guillemets_simples' => 'Вставити між “лапок”',
	'barre_indenter' => 'Добавить відступ',
	'barre_inserer_cadre' => 'Вставити форматований текст (cadre)', # MODIF
	'barre_inserer_caracteres' => 'Вставити спеціальні символи',
	'barre_inserer_code' => 'Виділення для програмного коду (code)', # MODIF
	'barre_intertitre' => '{{{Підзаголовок}}}',
	'barre_italic' => '{Курсив}',
	'barre_langue' => 'Абревіатури',
	'barre_lien' => 'Зробити [посиланням->http://...]',
	'barre_lien_externe' => 'Зовнішнє посилання',
	'barre_lien_input' => 'Вкажіть адресу для цього посилання (ви можете вказати її в форматі URL http://www.monsite.com або просто написати номер статті).',
	'barre_liste_ol' => 'Нумерований список',
	'barre_liste_ul' => 'Список',
	'barre_lorem_ipsum' => 'Вставити пустий абзац',
	'barre_lorem_ipsum_3' => 'Вставити три пустих абзаци',
	'barre_miseenevidence' => '[*Підсвітити*] текст',
	'barre_note' => 'Зробити [[виноску]]',
	'barre_paragraphe' => 'Створити абзац',
	'barre_petitescapitales' => 'Написати &lt;sc&gt;малими &lt;/sc&gt;',
	'barre_poesie' => 'Форматування для &lt;poesie&gt;поезії&lt;/poesie&gt;',
	'barre_preview' => 'Поперед.перегляд',
	'barre_quote' => '<quote>Цитата</quote>',
	'barre_stats' => 'Статистика',
	'barre_tableau' => 'Додати або редагувати вибрану таблицю',

	// C
	'config_info_enregistree' => 'Налаштування збережено',

	// E
	'editer' => 'Редагувати',
	'explication_barre_outils_public' => 'CSS і Javascript сценарії для панелей інструментів (extension Porte Plume) будуть завантажені на сайт, і панель форматування тексту буде виводитися у форумах, в модулі коментарів та інших місцях, якщо їх конфігурації це дозволяють.',
	'explication_barre_outils_public_2' => 'Щоб максимально полегшити сайт і зменшити час його завантаження ви можете вимкнути додавання цих файлів. Тоді користувачі не зможуть форматувати текст при додаванні коментарів та в інших модулях.',

	// I
	'info_barre_outils_public' => 'Панель інструментів на сайті',
	'info_porte_plume_titre' => 'Налаштування панелі інструментів',

	// L
	'label_barre_outils_public_non' => 'Не додавати скрипти панелі інструментів на фронтенд сайту',
	'label_barre_outils_public_oui' => 'Додати скрипти для панелі інструментів на фронтенд сайту',

	// V
	'voir' => 'Поперед.перегляд'
);
